==> enterprisemodules-ora_config-3.21.0.tar.gz: enterprisemodules-ora_config-3.21.0/lib/puppet/type/ora_exec.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_exec) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  extend PuppetX::EnterpriseModules::Oracle::TitleParser
  include PuppetX::EnterpriseModules::Oracle::DefaultSid

  desc <<-DESC
    This type allows you run a specific SQL statement or an sql file on a specified instance sid.

        ora_exec{"drop table application_users@sid":
          username => 'app_user',
          password => 'password,'
        }

    This statement will execute the sql statement `drop table application_users` on the instance names `instance`.

    You can use the `unless` parameter to only execute the statement in certain states. If the query specified in the
    `unless` parameter returns one or more records, the main statement is skipped.

        ora_exec{ "create synonym ${user}.${synonym} for USER.${synonym}":
          unless  => "select * from all_synonyms where owner=\'${user}\' and synonym_name=\'${synonym}\'",
        }

    You can also execute a script.

        ora_exec{"@/tmp/do_some_stuff.sql@sid":
          username  => 'app_user',
          password  => 'password,'
          logoutput => on_failure,  # can be true, false or on_failure
        }

    This statement will run the sqlscript `/tmp/do_some_stuff.sql` on the sid named `sid`. Use the `unless`
    parameter to just execute the script in certain situations.

    When you don't specify the username and the password, the type will connect as `sysdba`.


  DESC

  map_titles_to_attributes([
                             /^((@.*)@(.*))$/, [:name, :statement, :sid],
                             /^((.*)@(.*))$/,  [:name, :statement, :sid],
                             /^((@.*))$/,      [:name, :statement],
                             /^((.*))$/,       [:name, :statement]
                           ])

  map_title_to_sid(:statement)

  def refresh
    return unless provider.need_to_execute?

    provider.execute
    if parameters[:statement].sensitive
      Puppet.notice "#{path}: defined 'statement' as '[redacted]'"
    else
      Puppet.notice "#{path}: defined 'statement' as '#{statement}'"
    end
  end

  parameter :name
  property  :statement
  parameter :sid

  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :password
  parameter :username
  parameter :unless
  parameter :onlyif
  parameter :refreshonly
  parameter :report_errors
  parameter :mark_as_error

  ora_autorequire(:ora_user, :username)

  def onlyif_specified?
    !self[:onlyif].nil?
  end

  def unless_specified?
    !self[:unless].nil?
  end

  def report_errors?
    case self[:report_errors].to_s
    when 'true'
      true
    when 'false'
      false
    else
      fail 'invalid value for report_errors'
    end
  end
end

==> enterprisemodules-ora_config-3.22.2.tar.gz: enterprisemodules-ora_config-3.22.2/lib/puppet/type/ora_exec.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_exec) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  extend PuppetX::EnterpriseModules::Oracle::TitleParser
  include PuppetX::EnterpriseModules::Oracle::DefaultSid

  desc <<-DESC
    This type allows you run a specific SQL statement or an sql file on a specified instance sid.

        ora_exec{"drop table application_users@sid":
          username => 'app_user',
          password => 'password,'
        }

    This statement will execute the sql statement `drop table application_users` on the instance names `instance`.

    You can use the `unless` parameter to only execute the statement in certain states. If the query specified in the
    `unless` parameter returns one or more records, the main statement is skipped.

        ora_exec{ "create synonym ${user}.${synonym} for USER.${synonym}":
          unless  => "select * from all_synonyms where owner='${user}' and synonym_name='${synonym}'",
        }

    You can also execute a script.

        ora_exec{"@/tmp/do_some_stuff.sql@sid":
          username  => 'app_user',
          password  => 'password,'
          logoutput => on_failure,  # can be true, false or on_failure
        }

    This statement will run the sqlscript `/tmp/do_some_stuff.sql` on the sid named `sid`. Use the `unless`
    parameter to just execute the script in certain situations.

    When you don't specify the username and the password, the type will connect as `sysdba`.


  DESC

  map_titles_to_attributes([
                             /^((@.*)@(.*))$/, [:name, :statement, :sid],
                             /^((.*)@(.*))$/,  [:name, :statement, :sid],
                             /^((@.*))$/,      [:name, :statement],
                             /^((.*))$/,       [:name, :statement]
                           ])

  map_title_to_sid(:statement)

  def refresh
    return unless provider.need_to_execute?

    provider.execute
    if parameters[:statement].sensitive
      Puppet.notice "#{path}: defined 'statement' as '[redacted]'"
    else
      Puppet.notice "#{path}: defined 'statement' as '#{statement}'"
    end
  end

  parameter :name
  property  :statement
  parameter :sid

  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :password
  parameter :username
  parameter :unless
  parameter :onlyif
  parameter :refreshonly
  parameter :report_errors
  parameter :mark_as_error

  ora_autorequire(:ora_user, :username)

  def onlyif_specified?
    !self[:onlyif].nil?
  end

  def unless_specified?
    !self[:unless].nil?
  end

  def report_errors?
    case self[:report_errors].to_s
    when 'true'
      true
    when 'false'
      false
    else
      fail 'invalid value for report_errors'
    end
  end
end
